<script setup>
import AppLayoutBasic from "@/Layouts/AppLayoutBasic.vue";
import Welcome from "@/Jetstream/Welcome.vue";
import { Link, useForm } from '@inertiajs/inertia-vue3';
import DK_Button from '@/components/dk_Button.vue';
import JetModal from '@/Jetstream/Modal.vue';
import DK_Input from '@/components/dk_Input.vue';
import JetAuthenticationCardLogo from '@/Jetstream/AuthenticationCardLogo.vue';
import JetApplicationMark from '@/Jetstream/ApplicationMark.vue';

</script>

<template>
    <loader-component></loader-component>
    <Link id="routing" class="h-0 w-0 invisible" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('routing')"></Link>

    <div v-if="this.screen_width >= 768" style="height: calc(100vh)">

        <div class="h-full flex flex-col items-center px-72  overflow-y-scroll cursor-default" style=" background-image: url('/assets/images/backgrounds/background.jpg');
            height: 100%;
            background-position: center;
            background-repeat: no-repeat;
            background-size: cover;">

            <div class="h-9 self-center min-w-[12rem] mr-5 my-10 w-fit">
                <JetAuthenticationCardLogo />
            </div>

            <p class="text-white-snow font-light text-2xl pb-4  text-center w-fit">{{ "Reset password" }} </p>

            <div class="grid gap-x-8 px-8 py-4 gap-y-4 mb-10 font-light text-white-snow text-s baltoro-container max-w-sm h-fit">

                <div class="flex justify-center text-center text-xs max-width: 80%">
                    {{ this.$t("text." + "Reset password info") }}
                </div>

                <div class="w-full border-gray-semimedium border-t"></div>

                <div class="flex justify-center grid gap-x-8 px-4 gap-y-4 font-light text-white-snow text-s w-full h-fit">
                    <div class="w-full">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Password") }}</p>
                        <DK_Input id="id_user_password" type="password" :border="true" textPosition="center" width="full" @input="this.CheckButtonState()"/>
                    </div>

                    <div class="w-full">
                        <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Repeat password") }}</p>
                        <DK_Input id="id_user_repeat_password" type="password" :border="true" textPosition="center" width="full" @input="this.CheckButtonState()"/>
                    </div>

                    <div class="flex-col gap-2 py-2 flex justify-start items-start gap-x-2 text-xs rounded-md border border-gray-semimedium w-fit px-2 text-start w-full" >
                        <a class="flex flex-row gap-1 items-start justify-start" v-for="(step, key) in this.text_policies" :key="key"  v-bind:class="{'' : !step.bool, 'opacity-70' : step.bool}">
                            <span class="mt-[7px] inline-block w-1 h-1 rounded-full leading-12 bg-white" ></span>
                            <p>{{ step.text }}</p>
                        </a>
                    </div>

                    <div class="flex justify-center gap-4 pr-0.5">
                        <DK_Button color="blue" :fixedSize="true" :off="this.button_state" v-on:click="this.SaveEditPassword()">
                            {{ this.$t("general.Update") }}
                        </DK_Button>
                    </div>

                </div>
            </div>
        </div>
    </div>

    <div style="height: calc(100vh - 4.75rem);" v-else>

        <div class="h-full flex flex-col  items-center px-10  overflow-y-scroll cursor-default" style=" background-image: url('/assets/images/backgrounds/background.jpg');
            height: 100%;
            background-position: center;
            background-repeat: no-repeat;
            background-size: cover;">

            <div class="  h-9 self-center my-5 mr-5 max-w-[6.5rem]">
                <JetApplicationMark />
            </div>

            <p class="text-white-snow font-light text-2xl pb-4 ">{{ "Reset password" }} </p>

            <div class="grid gap-x-8 px-8 py-4 gap-y-4 mb-10 font-light text-white-snow text-s baltoro-container max-w-sm h-fit">

                <div class="">
                    <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Password") }}</p>
                    <DK_Input id="id_user_password" type="password" :border="true" textPosition="center" width="full" @input="this.CheckButtonState()"/>
                </div>

                <div class="">
                    <p class="text-cyan-text text-left ml-1">{{ this.$t("general." + "Repeat password") }}</p>
                    <DK_Input id="id_user_repeat_password" type="password" :border="true" textPosition="center" width="full" @input="this.CheckButtonState()"/>
                </div>

                <div class="flex flex-col gap-2 py-2 justify-start items-start gap-x-2 rounded-md text-xs border border-gray-semimedium w-fit px-2 text-start">
                    <div class="whitespace-nowrap flex flex-row justify-start items-start" v-for="(step, key) in this.text_policies" :key="key"  v-bind:class="{'' : !step.bool, 'opacity-70' : step.bool}" >
                        <span class="w-1 h-1 rounded-full leading-12 bg-white" ></span>
                        <p>{{ step.text }}</p>
                    </div>
                </div>

                <div class="flex justify-center gap-4 mt-4 pr-0.5">
                    <DK_Button color="blue" :fixedSize="true" :off="this.button_state" v-on:click="this.SaveEditPassword()">
                        {{ this.$t("general.Update") }}
                    </DK_Button>
                </div>

            </div>
        </div>
    </div>
</template>

<script>
export default {
    data() {
        return {
            screen_width: 0,
            demo_modal: false,
            button_state: true,
            text_policies: [
                {
                    text: this.$t("text." + "Password lettersNumbers"),
                    bool: false,
                    regex: /^(?=.*[a-zA-Z])(?=.*\d)/,
                },
                {
                    text: this.$t("text." + "Password upperCase"),
                    bool: false,
                    regex: /^(?=.*[a-z])(?=.*[A-Z])/,
                },
                {
                    text: this.$t("text." + "Password specialCharacters"),
                    bool: false,
                    regex: /[!@#$%^&*(),.?":{}|<>-_]/,
                },
                {
                    text: this.$t("text." + "Password length"),
                    bool: false,
                    regex: /^.{8,}$/,
                },
                {
                    text: this.$t("text." + "Password blankSpaces"),
                    bool: false,
                    regex: /^\S*$/,
                },
                {
                    text: this.$t("text." + "Password matchPass"),
                    bool: false,
                    regex: '',
                },
            ],
        };
    },
    props: ["user"],

    beforeCreate: function () {
        this.$i18n.locale = this.user.language;
    },

    beforeMount() {
        this.screen_width = window.screen.width;
    },

    mounted() {
        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        /*window.emitter.emit(
            'AppLayout_alert',
            true,
            this.$t('text.Passwords Policies Title'),
            this.$t('text.PasswordsPolicies'),
            '24rem'
        )*/
    },

    methods: {

        CheckButtonState(){

            this.button_state = !this.CheckPasswordPolicies(
                document.getElementById('id_user_password').value,
                document.getElementById('id_user_repeat_password').value
            )

            let text = (typeof document.getElementById('id_user_password').value === 'string' && document.getElementById('id_user_password').value != "") ? document.getElementById('id_user_password').value : null;

            this.text_policies.forEach( (step, index) => {

                if(index != this.text_policies.length - 1){

                    let regex = step.regex;

                    if(text != null){
                        this.text_policies[index].bool = regex.test(text);
                    }else{
                        this.text_policies[index].bool = false;
                    }

                } else {
                    this.text_policies[index].bool = document.getElementById('id_user_password').value === document.getElementById('id_user_repeat_password').value;
                }

            })

        },

        SaveEditPassword(){

            let user_password = document.getElementById('id_user_password').value
            let user_repeat_password = document.getElementById('id_user_repeat_password').value

            if(this.CheckPasswordPolicies(user_password, user_repeat_password)){
                const data = {
                    "password": user_password,
                    "confirm_password": user_repeat_password,
                };

                window.emitter.emit('changeLoaderStatus', true, 'orbit')

                axios({
                    method: 'post',
                    url: window.location.origin + '/api/user/password_reset/' + this.user.id,
                    headers: {
                        'Accept': 'application/json',
                        'Content-Type': 'application/json',
                        'Authorization': 'Bearer ' + this.user.token
                    },
                    data: data
                })
                .then((response) => {

                    if(!response.data){
                        document.getElementById('id_user_password').value = '';
                        document.getElementById('id_user_repeat_password').value = '';
                        window.emitter.emit('changeLoaderStatus', false, 'orbit')
                        window.alert( this.$t('text.Stored password'));
                    }else{
                        this.Login(user_password);
                    }
                })
                .catch((error) => {
                    if(error.response && error.response.status && error.response.status == 429){
                        window.alert( this.$t('text.Api attempts'));
                    }else{
                        return "Failed!", error;
                    }

                });
            }
        },

        CheckPasswordPolicies(password1, password2) {

            const conditions = [
                /[a-z]/,
                /[A-Z]/,
                /\d/,
                /[!@#$%^&*(),.?":{}|<>-_]/,
                /^.{8,}$/
            ];

            if(password2 && (password1 === password2)){
                return conditions.every(condition => condition.test(password1));
            }else{
                return false;
            }
        },

        Login(user_password) {
            const form = useForm({
                user: this.user.user,
                password: user_password,
                remember: false,
            });

            window.emitter.emit('changeLoaderStatus', true, 'orbit');

            form.transform(data => ({
                ...data,
            })).post(route('login'), {
                onFinish: () => {
                    form.reset('password');
                    window.emitter.emit('changeLoaderStatus', false, 'orbit');
                },
                onError: (error) => {
                    console.error(error);
                    window.emitter.emit('changeLoaderStatus', false, 'orbit');
                }
            });
        },
    },
};
</script>
